Print proto_ipms or *_ipm objects
Generics for IPM classes
# S3 method for proto_ipm
print(x, ...)# S3 method for simple_di_det_ipm
print(
x,
comp_lambda = TRUE,
type_lambda = "last",
sig_digits = 3,
check_conv = TRUE,
...
)
# S3 method for simple_dd_det_ipm
print(x, comp_lambda = TRUE, type_lambda = "last", sig_digits = 3, ...)
# S3 method for simple_di_stoch_kern_ipm
print(x, comp_lambda = TRUE, type_lambda = "stochastic", sig_digits = 3, ...)
# S3 method for simple_dd_stoch_kern_ipm
print(x, comp_lambda = TRUE, type_lambda = "stochastic", sig_digits = 3, ...)
# S3 method for simple_di_stoch_param_ipm
print(x, comp_lambda = TRUE, type_lambda = "stochastic", sig_digits = 3, ...)
# S3 method for simple_dd_stoch_param_ipm
print(x, comp_lambda = TRUE, type_lambda = "stochastic", sig_digits = 3, ...)
# S3 method for general_di_det_ipm
print(
x,
comp_lambda = TRUE,
type_lambda = "last",
sig_digits = 3,
check_conv = TRUE,
...
)
# S3 method for general_dd_det_ipm
print(x, comp_lambda = TRUE, type_lambda = "last", sig_digits = 3, ...)
# S3 method for general_di_stoch_kern_ipm
print(x, comp_lambda = TRUE, type_lambda = "stochastic", sig_digits = 3, ...)
# S3 method for general_dd_stoch_kern_ipm
print(x, comp_lambda = TRUE, type_lambda = "stochastic", sig_digits = 3, ...)
# S3 method for general_di_stoch_param_ipm
print(x, comp_lambda = TRUE, type_lambda = "stochastic", sig_digits = 3, ...)
# S3 method for general_dd_stoch_param_ipm
print(x, comp_lambda = TRUE, type_lambda = "stochastic", sig_digits = 3, ...)
x invisibly.
An object of class proto_ipm or produced by make_ipm().
Ignored
A logical indicating whether or not to calculate lambdas for the iteration kernels and display them.
Either 'all' or 'stochastic'. See
lambda for more details.
The number of significant digits to round to if
comp_lambda = TRUE.
A logical: for deterministic models, check if population state
has converged to asymptotic dynamics? If TRUE and the model has not
converged, a message will be printed.
For printing proto_ipm objects, indices are wrapped in
<index> to assist with debugging. These are not carried into the model,
just a visual aid.